[x264-devel] commit: Save more memory with weightp in >8-bit (Yasuhiro Ikeda )
git at videolan.org
git at videolan.org
Wed Dec 15 04:19:32 CET 2010
x264 | branch: master | Yasuhiro Ikeda <wipple625 at gmail.com> | Thu Dec 9 11:59:49 2010 +0900| [39a5799f9af0b117181f5f6866f292733876a173] | committer: Jason Garrett-Glaser
Save more memory with weightp in >8-bit
> http://git.videolan.org/gitweb.cgi/x264.git/?a=commit;h=39a5799f9af0b117181f5f6866f292733876a173
---
common/macroblock.c | 4 ++--
1 files changed, 2 insertions(+), 2 deletions(-)
diff --git a/common/macroblock.c b/common/macroblock.c
index 9075efc..f68fd6d 100644
--- a/common/macroblock.c
+++ b/common/macroblock.c
@@ -272,8 +272,8 @@ int x264_macroblock_cache_allocate( x264_t *h )
luma_plane_size = h->fdec->i_stride[0] * (h->mb.i_mb_height*16+2*i_padv);
if( h->param.analyse.i_weighted_pred == X264_WEIGHTP_SMART )
- //SMART can weight one ref and one offset -1
- numweightbuf = 2;
+ //smart can weight one ref and one offset -1 in 8-bit
+ numweightbuf = 1 + (BIT_DEPTH == 8);
else
//simple only has one weighted ref
numweightbuf = 1;
More information about the x264-devel
mailing list